import React, { useState, useEffect } from 'react'
import {
    ValidatorForm,
    TextValidator,
    SelectValidator,
} from 'react-material-ui-form-validator'
import {
    Button,
    Grid,
    MenuItem,
    FormControlLabel,
    Checkbox,
    Typography,
} from '@material-ui/core'
import { createFunction } from 'app/apis/Functions/function'
import { showLoading, hideLoading } from 'app/redux/actions/loadingAction'
import { toast } from 'react-toastify'
import { Breadcrumb, SimpleCard } from 'app/components'
import { Link, useHistory, useLocation } from 'react-router-dom'
import { trimObject, encryString } from 'app/config/Function'
import { connect } from 'react-redux'
import {
    dropdownDepartment,
    dropdownUserGroup,
} from 'app/apis/Functions/dropdown'
import PickerImage from 'app/components/Input/PickerImage'
import {
    actionByGroup,
    updateEmployee,
    detailEmployee,
} from 'app/apis/Functions/Employee'

const SimpleForm = (props) => {
    const history = useHistory()
    const location = useLocation()

    const [state, setState] = useState({})
    const [listDepartment, setListDepartment] = useState([])
    const [listDrop, setListDrop] = useState([])
    const [listAction, setListAction] = useState([])
    const [image, setImage] = useState()
    const [listChecked, setListChecked] = useState([])
    const [role, setRole] = useState()
    const [listGroup, setGroup] = useState([])

    useEffect(() => {
        getData()
        getListDepartments()
        getUserGroup()
    }, [])
    useEffect(() => {
        getListAction()
        setListChecked([])
    }, [role])

    const getData = async () => {
        props.showLoading()
        const res = await detailEmployee(location.state, {})
        props.hideLoading()
        console.log('res.data.data', res.data.data)
        if (res.data.code == 200 && res.data.data) {
            setRole(res.data.data.user_group_id)
            setState(res.data.data)
            setImage(res.data.data.avatar)
            if (res.data.data.userPermissions.length > 0) {
                const newList = res.data.data.userPermissions.map(
                    (e) => e.action_id
                )
                setListChecked(newList)
            }
        } else if (res.data.code == 401) {
            setTimeout(() => {
                history.push('/')
            }, 100)
        } else {
            toast.error('Lấy thông tin bản ghi thất bại!', {
                theme: 'colored',
            })
        }
    }

    const getListAction = async () => {
        if (role) {
            const res = await actionByGroup(role, {})
            if (res.data.code == 200 && res.data.data) {
                setListAction(res.data.data.userGroupPermissions)
            } else if (res.data.code == 401) {
                setTimeout(() => {
                    history.push('/')
                }, 100)
            } else {
                toast.error('Lấy giữ liệu thất bại !', {
                    theme: 'colored',
                })
            }
        }
    }

    const getListDepartments = async () => {
        const res = await dropdownDepartment({})
        if (res.data.code == 200 && res.data.data) {
            setListDepartment(res.data.data)
        } else if (res.data.code == 401) {
            setTimeout(() => {
                history.push('/')
            }, 100)
        } else {
            toast.error('Lấy giữ liệu thất bại !', {
                theme: 'colored',
            })
        }
    }

    const getUserGroup = async () => {
        const res = await dropdownUserGroup({})
        if (res.data.code == 200 && res.data.data) {
            setGroup(res.data.data)
        } else if (res.data.code == 401) {
            setTimeout(() => {
                history.push('/')
            }, 100)
        } else {
            toast.error('Lấy giữ liệu thất bại !', {
                theme: 'colored',
            })
        }
    }

    const handleSubmit = async (event) => {
        const newValue = trimObject(state)
        if (listChecked.length > 0) {
            if (image) {
                const newList = listChecked.map((e) => {
                    return { action_id: parseInt(e) }
                })
                props.showLoading()
                const res = await updateEmployee({
                    ...newValue,
                    user_group_id: role,
                    is_customer_data_manager: newValue.is_customer_data_manager
                        ? newValue.is_customer_data_manager
                        : false,
                    userPermissions: newList,
                    avatar: image,
                    status: 1,
                })
                console.log(res)
                props.hideLoading()
                if (res.data.code == 200) {
                    history.push('/employee')
                    if (res.data.code == 200) {
                        toast.success('Cập nhật nhân viên thành công!', {
                            theme: 'colored',
                        })
                    }
                } else {
                    toast.error('Cập nhật nhân viên thất bại!', {
                        theme: 'colored',
                    })
                }
            } else {
                toast.warning('Bạn chưa chọn ảnh đại diện cho nhân viên!', {
                    theme: 'colored',
                })
            }
        } else {
            toast.warning('Bạn chưa thêm quyền cho nhân viên!', {
                theme: 'colored',
            })
        }
    }

    const handleChange = (event) => {
        event.persist()
        setState({
            ...state,
            [event.target.name]: event.target.value,
        })
    }

    const handleCheck = (event) => {
        setState({ ...state, [event.target.name]: event.target.checked })
    }

    const onFileChange = (url) => {
        console.log(url)
        setImage(url)
    }

    const onPicker = (value) => {
        if (value.target.checked) {
            const newList = listChecked.concat(parseInt(value.target.name))
            setListChecked(newList)
        } else {
            const newList = listChecked.filter((e) => {
                return e != value.target.name
            })
            setListChecked(newList)
        }
    }

    const {
        username,
        password,
        phone,
        email,
        address,
        full_name,
        organization_id,
        is_customer_data_manager,
    } = state
    return (
        <div className="m-sm-30">
            <div className="mb-sm-30">
                <div className="mb-sm-30">
                    <Breadcrumb
                        routeSegments={[
                            {
                                name: 'Danh sách  nhân viên',
                                path: '/employee',
                            },
                            { name: 'Cập nhật nhân viên' },
                        ]}
                    />
                </div>
                <SimpleCard>
                    <ValidatorForm onSubmit={handleSubmit} onError={() => null}>
                        <Grid container spacing={3}>
                            <Grid item lg={12} md={12} sm={12} xs={12}>
                                <PickerImage
                                    images={image}
                                    onFileChange={onFileChange}
                                    title={'Ảnh đại diện'}
                                />
                            </Grid>
                            <Grid item lg={6} md={6} sm={12} xs={12}>
                                <TextValidator
                                    variant="outlined"
                                    className="mb-4 w-full"
                                    label="Tên nhân viên *"
                                    onChange={handleChange}
                                    type="text"
                                    name="full_name"
                                    value={full_name || ''}
                                    validators={['required']}
                                    errorMessages={[
                                        'Không được để trống trường này',
                                    ]}
                                />
                            </Grid>
                            <Grid item lg={6} md={6} sm={12} xs={12}>
                                <TextValidator
                                    variant="outlined"
                                    className="mb-4 w-full"
                                    label="Số điện thoại *"
                                    onChange={handleChange}
                                    type="text"
                                    name="phone"
                                    value={phone || ''}
                                    validators={[
                                        'required',
                                        'isNumber',
                                        'minStringLength:10',
                                        'maxStringLength:15',
                                    ]}
                                    errorMessages={[
                                        'Không được để trống trường này',
                                        'Trường này phải nhập số ',
                                        'Số điện thoại phải có ít nhất 10 chữ số',
                                        'Số điện thoại nhiều nhất chỉ có 15 chữ số',
                                    ]}
                                />
                            </Grid>
                            <Grid item lg={6} md={6} sm={12} xs={12}>
                                <TextValidator
                                    variant="outlined"
                                    className="mb-4 w-full"
                                    label="Email *"
                                    onChange={handleChange}
                                    type="text"
                                    name="email"
                                    value={email || ''}
                                    validators={['required', 'isEmail']}
                                    errorMessages={[
                                        'Không được để trống trường này',
                                        'Email không hợp lệ',
                                    ]}
                                />
                            </Grid>

                            <Grid item lg={6} md={6} sm={12} xs={12}>
                                <TextValidator
                                    variant="outlined"
                                    className="mb-4 w-full"
                                    label="Địa chỉ *"
                                    onChange={handleChange}
                                    type="text"
                                    name="address"
                                    value={address || ''}
                                    validators={['required']}
                                    errorMessages={[
                                        'Không được để trống trường này',
                                    ]}
                                />
                            </Grid>

                            <Grid item lg={6} md={6} sm={12} xs={12}>
                                <TextValidator
                                    variant="outlined"
                                    className="mb-4 w-full"
                                    label="Tài khoản *"
                                    disabled
                                    onChange={handleChange}
                                    type="text"
                                    name="username"
                                    value={username || ''}
                                    validators={['required']}
                                    errorMessages={[
                                        'Không được để trống trường này',
                                    ]}
                                />
                            </Grid>

                            <Grid lg={6} md={6} sm={12} xs={12} item>
                                <SelectValidator
                                    variant={'outlined'}
                                    label={'Phòng ban *'}
                                    className="mb-4 w-full"
                                    value={organization_id || ''}
                                    displayEmpty
                                    name="organization_id"
                                    onChange={handleChange}
                                    validators={['required']}
                                    errorMessages={[
                                        'Không được để trống trường này',
                                    ]}
                                >
                                    {listDepartment.map((e) => (
                                        <MenuItem value={e.id}>
                                            {e.name}
                                        </MenuItem>
                                    ))}
                                </SelectValidator>
                            </Grid>
                            <Grid lg={6} md={6} sm={12} xs={12} item>
                                {role ? (
                                    <SelectValidator
                                        variant={'outlined'}
                                        label={'Nhóm quyền *'}
                                        className="w-full"
                                        value={role}
                                        displayEmpty
                                        onChange={(e) =>
                                            setRole(e.target.value)
                                        }
                                        validators={['required']}
                                        errorMessages={[
                                            'Không được để trống trường này',
                                        ]}
                                    >
                                        {listGroup.map((e) => (
                                            <MenuItem value={e.id}>
                                                {e.name}
                                            </MenuItem>
                                        ))}
                                    </SelectValidator>
                                ) : null}
                            </Grid>

                            <Grid lg={12} md={12} sm={12} xs={12} item>
                                <FormControlLabel
                                    className="min-w-288"
                                    control={
                                        <Checkbox
                                            size="small"
                                            color="primary"
                                            name="is_customer_data_manager"
                                            onChange={handleCheck}
                                            checked={
                                                is_customer_data_manager ||
                                                false
                                            }
                                        />
                                    }
                                    label="Quản lý thông tin khách hàng"
                                />
                            </Grid>

                            <Grid item xs={12} sm={12}>
                                <Typography variant={'h6'}>
                                    Danh sách hành động
                                </Typography>
                                <Grid row container item xs={12} sm={12}>
                                    {listAction.map((e) => (
                                        <Grid item xs={3}>
                                            <FormControlLabel
                                                label={e.action_name}
                                                control={
                                                    <Checkbox
                                                        checked={listChecked.includes(
                                                            e.action_id
                                                        )}
                                                        size="small"
                                                        color="primary"
                                                        onChange={onPicker}
                                                        name={e.action_id}
                                                    />
                                                }
                                            />
                                        </Grid>
                                    ))}
                                </Grid>
                            </Grid>
                        </Grid>
                        <Grid container justify={'flex-end'}>
                            <Link to="/employee">
                                <Button
                                    style={{
                                        marginRight: 20,
                                    }}
                                    color="inherit"
                                    variant="contained"
                                    onClick={() => {}}
                                >
                                    <span className="capitalize">Quay lại</span>
                                </Button>
                            </Link>
                            <Button
                                color="primary"
                                variant="contained"
                                type="submit"
                            >
                                <span className="capitalize">Cập nhật</span>
                            </Button>
                        </Grid>
                    </ValidatorForm>
                </SimpleCard>
            </div>
        </div>
    )
}

const mapStateToProps = (state) => {
    return {}
}
export default connect(mapStateToProps, { showLoading, hideLoading })(
    SimpleForm
)
